<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="af">
<context>
    <name>AppSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="42"/>
        <source>Check transfer application will automatically install the corresponding UOS version of the application.</source>
        <translation>Kontroleer omskakelingsprogramma sal self die ooreenstemmende versie van die toepassing op UOS installeer.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="56"/>
        <source>Confirm</source>
        <translation>Bevestig</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="77"/>
        <source>Application</source>
        <translation>Toepassing</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="77"/>
        <source>Recommendation</source>
        <translation>Aanbeveling</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="102"/>
        <source>Transferable</source>
        <translation>Omskakelbaar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.cpp" line="112"/>
        <source>Not Suitable</source>
        <translation>Nie geskik nie</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.h" line="46"/>
        <source>Select apps to transfer</source>
        <translation>Kies toepassings om omskakel</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/appselectwidget.h" line="47"/>
        <source>Please select the applications to back up</source>
        <translation>Kies asseblief die toepassings wat jy wil backup</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <location filename="../../src/apps/data-transfer/main.cpp" line="86"/>
        <source>UOS data transfer</source>
        <translation>UOS data omskakeling</translation>
    </message>
    <message>
        <location filename="../../src/apps/data-transfer/main.cpp" line="91"/>
        <source>UOS transfer tool enables one click migration of your files, personal data, and applications to UOS, helping you seamlessly replace your system.</source>
        <translation>UOS omskakelingsinstrument maak moontlik vir een-klik omskakeling van jou lêers, persoonlike data en toepassings na UOS, wat jou help om jou stelsel glad te vervang.</translation>
    </message>
</context>
<context>
    <name>ChooseWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="35"/>
        <source>Export to local directory</source>
        <translation>Druk uit na plaaslike map</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="41"/>
        <source>Select a transfer way</source>
        <translation>Kies &apos;n omskakelingswyse</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="56"/>
        <source>Unable to connect to the network， please check your network connection or select export to local directory.</source>
        <translation>Nie in staat om aan die netwerk te verbind nie, kontroleer asseblief jou netwerkverbinding of kies uitbreng na plaaslike map.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.cpp" line="69"/>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="33"/>
        <source>From Windows PC</source>
        <translation>Vanaf Windows PC</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/choosewidget.h" line="39"/>
        <source>Import from backup files</source>
        <translation>Inlewer van backuplêers</translation>
    </message>
</context>
<context>
    <name>ConfigSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="39"/>
        <source>Check transfer configuration will automatically apply to UOS.</source>
        <translation>Kontroleer omskakelingskonfigurasiestel sal self op UOS toepasbaar wees.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="51"/>
        <source>Confirm</source>
        <translation>Bevestig</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="75"/>
        <source>Browser bookmarks</source>
        <translation>Browser bladmerk</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="75"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="116"/>
        <source>Recommendation</source>
        <translation>Aanbeveling</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="98"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="139"/>
        <source>Transferable</source>
        <translation>Omskakelbaar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="116"/>
        <source>Personal Settings</source>
        <translation>Persoonlike instellings</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.cpp" line="138"/>
        <source>Customized Wallpaper</source>
        <translation>Aangepaste muurkaart</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.h" line="49"/>
        <source>Select the configuration to transfer</source>
        <translation>Kies die konfigurasiestel om omskakel</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/configselectwidget.h" line="50"/>
        <source>Please select the configurations to back up</source>
        <translation>Kies asseblief die konfigurasiestelle wat jy wil backup</translation>
    </message>
</context>
<context>
    <name>ConnectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="36"/>
        <source>Ready to connect</source>
        <translation>Klaar om te verbind</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="41"/>
        <source>Please open data transfer on Windows, and imput the IP and connect code</source>
        <translation>Ou asseblief data omskakeling op Windows, en voer die IP en verbindingskode in</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="48"/>
        <source>Download Windows client</source>
        <translation>Laai Windows klient af</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="59"/>
        <source>Connect code is expired, please refresh for new code</source>
        <translation>Die skakode is verouderd, skakel asseblief vir &apos;n nuwe skakode</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="75"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="104"/>
        <source>computer</source>
        <translation>rekenaar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="107"/>
        <source>Local IP</source>
        <translation>Lokale IP</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="163"/>
        <source>Refresh</source>
        <translation>Vernu</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="171"/>
        <source>The code will be expired in</source>
        <translation>Die skakode sal verouder in</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/connectwidget.cpp" line="171"/>
        <source>please input connect code as soon as possible</source>
        <translation>skakode asseblief byvoeg so gou moontlik</translation>
    </message>
</context>
<context>
    <name>CreateBackupFileWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="87"/>
        <source>Create data backup</source>
        <translation>Skep data-backup</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="95"/>
        <source>File information</source>
        <translation>Bestand informasie</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="115"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="133"/>
        <source>size:0B</source>
        <translation>grootte:0B</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="152"/>
        <source>Location</source>
        <translation>Lokasie</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="162"/>
        <source>(Select Backup Disk)</source>
        <translation>(Kies Backup Skerm)</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="187"/>
        <source>Insufficient space in the selected disk, please clean the space</source>
        <translation>Onvoldoende ruimte op die gekiesde skerm, skakel asseblief die ruimte vry</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="195"/>
        <source>Backup</source>
        <translation>Backup</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="193"/>
        <source>Cancel</source>
        <translation>Kanselleer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="339"/>
        <source>Size:%1</source>
        <translation>Grootte:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="382"/>
        <source>local disk</source>
        <translation>lokale skerm</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/createbackupfilewidget.cpp" line="388"/>
        <source>%1/%2 available</source>
        <translation>&apos;%1/%2 beskikbaar&apos;</translation>
    </message>
</context>
<context>
    <name>CustomMessageBox</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="66"/>
        <source>Reselect</source>
        <translation>Herkie</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="81"/>
        <source>Continue</source>
        <translation>Voortgaan</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="138"/>
        <source>The presence of outstanding transfer tasks between you and the target device has been detected.</source>
        <translation>Die aanwesigheid van onvoltooide oordraaftaak tussen jou en die doelrekenaar is gedetecteer.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/custommessagebox.cpp" line="138"/>
        <source>Do you want to continue with the last transfer?</source>
        <translation>Wen wil jy voortgaan met die laaste oordraaftaak?</translation>
    </message>
</context>
<context>
    <name>ErrorWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="54"/>
        <source>Transfer will be completed in</source>
        <translation>Die oordraaftaak sal voltooi word in</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="69"/>
        <source>Try again</source>
        <translation>Probeer weer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.cpp" line="66"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="29"/>
        <source>Network Error</source>
        <translation>Netwerk fout</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="30"/>
        <source>Transfer interrupted</source>
        <translation>Oordraaftaak onderbreek</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="32"/>
        <source>The network disconnected, transfer failed, please connect the network and try again</source>
        <translation>Die netwerk is afgesny, oordraaftaak het misluk, skakel asseblief die netwerk weer aan en probeer weer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="34"/>
        <source>Insufficient space in UOS, please clear at least %1 GB and try again</source>
        <translation>Onvoldoende ruimte in UOS, skakel asseblief ten minste %1 GB vry en probeer weer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/errorwidget.h" line="36"/>
        <source>Insufficient space in UOS, Please reserve enough space</source>
        <translation>Nie genoeg spasie in UOS, asseblief reserveer genoeg spasie</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="50"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="50"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="60"/>
        <source>When transfer completed, the data will be placed in the user&apos;s home directory</source>
        <translation>Wanneer die oordrag voltooi is, sal die data in die gebruiker se huismap geplaas word</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="73"/>
        <source>Confirm</source>
        <translation>Bevestig</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.cpp" line="71"/>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.h" line="56"/>
        <source>Select the file to transfer</source>
        <translation>Kies die lêer wat oorgedrag moet word</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/fileselectwidget.h" line="57"/>
        <source>Please select the files to back up</source>
        <translation>Asseblief kies die lêers wat gekopieer moet word</translation>
    </message>
</context>
<context>
    <name>NetworkDisconnectionWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="34"/>
        <source>The network has been disconnected. Please check your network</source>
        <translation>Die netwerk is afgesluit. Asseblief kontroleer u netwerk</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="40"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/networkdisconnectionwidget.cpp" line="41"/>
        <source>Try again</source>
        <translation>Probeer weer</translation>
    </message>
</context>
<context>
    <name>ProcessWindow</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="297"/>
        <source>Installing</source>
        <translation>Installeer</translation>
    </message>
</context>
<context>
    <name>PromptWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="29"/>
        <source>Before tranfer</source>
        <translation>Voordat u oordrag begin</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="34"/>
        <source>Data transfer requires some time, to avoid interrupting the migration due to low battery, please keep connect to the  power.</source>
        <translation>Data-oordrag neem &apos;n paar tyd in, om te voorkom dat die migrasie onderbreek word deur laag batterie, asseblief bly aangesluit by die krag.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="36"/>
        <source>Other applications may slowdown the transfer speed. For smoother experience, please close other applications.</source>
        <translation>Ander toepassings kan die oordrag spoed vertraag. Vir &apos;n gladder ervaring, asseblief sluit ander toepassings af.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="38"/>
        <source>For the security of your transfer, please use a trusted network.</source>
        <translation>Vir die veiligheid van u oordrag, asseblief gebruik &apos;n vertroude netwerk.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="62"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/promptwidget.cpp" line="64"/>
        <source>Confirm</source>
        <translation>Bevestig</translation>
    </message>
</context>
<context>
    <name>ReadyWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="48"/>
        <source>Ready to connect</source>
        <translation>Klaar om te verbind</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="52"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="59"/>
        <source>Please input the IP of UOS</source>
        <translation>Asseblief voer die IP van UOS in</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="79"/>
        <source>Please open data transfer on UOS, and get the IP</source>
        <translation>Asseblief oop data-oordrag op UOS, en kry die IP</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="85"/>
        <source>Connect code</source>
        <translation>Verbindkode</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="95"/>
        <source>Please input the connect code on UOS</source>
        <translation>Asseblief voer die verbindkode in op UOS</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="118"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="33"/>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="112"/>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="167"/>
        <source>connect...</source>
        <translation>verbind...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="120"/>
        <source>Connect</source>
        <translation>Verbind</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/readywidget.cpp" line="258"/>
        <source>Failed to connect, please check your input</source>
        <translation>Kon nie verbind nie, asseblief kyk na u invoer</translation>
    </message>
</context>
<context>
    <name>ResultDisplayWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="128"/>
        <source>Transfer completed partially</source>
        <translation>Oordrag voltooi gedeeltelik</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="32"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="125"/>
        <source>Transfer completed</source>
        <translation>Oordrag voltooi</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="38"/>
        <source>Partial information migration failed, please go to UOS for manual transfer</source>
        <translation>Gedeelte van die inligting migrasie het misluk, gaan na UOS vir manuele oorgang</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="50"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/resultdisplay.cpp" line="52"/>
        <source>Exit</source>
        <translation>Afsluit</translation>
    </message>
</context>
<context>
    <name>SelectItem</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="216"/>
        <source>Selected:0</source>
        <translation>Gekoos:0</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="237"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="239"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="241"/>
        <source>Selected:%1</source>
        <translation>Gekoos:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="304"/>
        <source>Edit</source>
        <translation>Wysig</translation>
    </message>
</context>
<context>
    <name>SelectMainWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="90"/>
        <source>File</source>
        <translation>Bestand</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="95"/>
        <source>App</source>
        <translation>Toepassing</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="97"/>
        <source>Config</source>
        <translation>Konfiguratie</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.cpp" line="112"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="72"/>
        <source>Select data to transfer</source>
        <translation>Kies data om oor te dra</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="73"/>
        <source>Please select the content to back up</source>
        <translation>Kies asseblief die inhoud wat u moet terugdra</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="74"/>
        <source>Start transfer</source>
        <translation>Begin oorgang</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/selectmainwidget.h" line="75"/>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
</context>
<context>
    <name>SettingHelper</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="63"/>
        <source>Profiles</source>
        <translation>Profiels</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="63"/>
        <source>Wrong or missing profile</source>
        <translation>Verkeerde of ontbrekende profiel</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="111"/>
        <source>My Wallpaper</source>
        <translation>My Afgifte</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="111"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="146"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="234"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="268"/>
        <source>Transfer completed</source>
        <translation>Oorgang voltooi</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="133"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="143"/>
        <source>Browser Bookmarks</source>
        <translation>Browser Boekmerke</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="146"/>
        <source>BrowserBookMark</source>
        <translation>BrowserBoekmerk</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="176"/>
        <source>is installed</source>
        <translation>is geïnstalleer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="200"/>
        <source>Installing</source>
        <translation>Beïnstalleer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="268"/>
        <source>Transfer failed</source>
        <translation>Oorgang het misluk</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="133"/>
        <source>Format error</source>
        <translation>Formaatfout</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="143"/>
        <source>Setup failed, configuration can be imported manually</source>
        <translation>Instelling het misluk, konfiguratie kan manueel ingevoer word</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="157"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="188"/>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="238"/>
        <source>Installation failed, please go to the app store to install</source>
        <translation>Installatie het misluk, gaan asseblief na die toepassingswinkel om te installeer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/settinghepler.cpp" line="249"/>
        <source>Transfer Complete</source>
        <translation>Oorgang Voltooi</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="21"/>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="22"/>
        <source>Pictures</source>
        <translation>Afbeeldings</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="23"/>
        <source>Documents</source>
        <translation>Dokumente</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="24"/>
        <source>Downloads</source>
        <translation>Laai af</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="25"/>
        <source>Music</source>
        <translation>Muziek</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="26"/>
        <source>Desktop</source>
        <translation>Lessenaar</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="80"/>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="351"/>
        <source>Select:%1</source>
        <translation>Kies:%1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/siderbarwidget.cpp" line="225"/>
        <source>local disk</source>
        <translation>lokale skerm</translation>
    </message>
</context>
<context>
    <name>StartWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="35"/>
        <source>UOS data transfer</source>
        <translation>Data-oordeling vir UOS</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="39"/>
        <source>UOS transfer tool enables one click migration of your files, personal data, and applications to
UOS, helping you seamlessly replace your system.</source>
        <translation>Die UOS-oordelingsinstrument maak dit moontlik om jou lêers, persoonlike data en toepassings met een klik na UOS oor te dra, wat u help om jou stelsel glad te vervang.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/connect/startwidget.cpp" line="46"/>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
</context>
<context>
    <name>TransferHandle</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/utils/transferworker.cpp" line="326"/>
        <source>Transfering</source>
        <translation>Oordeling</translation>
    </message>
</context>
<context>
    <name>TransferringWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="42"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="193"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="230"/>
        <source>Transferring...</source>
        <translation>Oordeling...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="57"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="191"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="229"/>
        <source>Calculationing...</source>
        <translation>Berekening...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="63"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="132"/>
        <source>Show processes</source>
        <translation>Toon prosesse</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="119"/>
        <source>Hide processes</source>
        <translation>Versteek prosesse</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="154"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="195"/>
        <source>Transfer will be completed in %1 minutes</source>
        <translation>Die oordeling sal voltooi wees in %1 minute</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="171"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="237"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="243"/>
        <source>Transfering</source>
        <translation>Oordeling</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="199"/>
        <source>Transfer will be completed in %1 secondes</source>
        <translation>Die oordeling sal voltooi wees in %1 sekondes</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="202"/>
        <source>Transfer will be completed in --</source>
        <translation>Die oordeling sal voltooi wees in --</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/transferringwidget.cpp" line="237"/>
        <source>Decompressing</source>
        <translation>Ontpakteer</translation>
    </message>
</context>
<context>
    <name>UnzipWorker</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/unzipwoker.cpp" line="126"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/unzipwoker.cpp" line="137"/>
        <source>Decompressing</source>
        <translation>Ontpakteer</translation>
    </message>
</context>
<context>
    <name>UploadFileFrame</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="197"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="256"/>
        <source>Drag file here </source>
        <translation>Sleep lêer hier </translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="202"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="257"/>
        <source>Import file</source>
        <translation>Importeer lêer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="276"/>
        <source>Only .zip is supported, please</source>
        <translation>Slegs .zip word ondersteun, asseblief</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="277"/>
        <source>reselect</source>
        <translation>kies weer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="351"/>
        <source>select zip file</source>
        <translation>kies zip-lêer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="351"/>
        <source>ZIP file (*.zip)</source>
        <translation>ZIP-lêer (*.zip)</translation>
    </message>
</context>
<context>
    <name>UploadFileWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="40"/>
        <source>Select data transfer file</source>
        <translation>Kies data-oordelingslêer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="49"/>
        <source>File error, cannot transfer, please reselect</source>
        <translation>Lêerfout, kan nie oordel, asseblief kies weer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="62"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="64"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="108"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="113"/>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="69"/>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="76"/>
        <source>Retry</source>
        <translation>Probeer weer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="122"/>
        <source>The file is corrupted and cannot be migrated. Please replace it with a backup file.</source>
        <translation>Die lêer is beskadig en kan nie oorgedra word nie. Vennig dit met &apos;n back-up lêer.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/backupload/uploadfilewidget.cpp" line="133"/>
        <source>Insufficient space on UOS. Please reserve at least %1G of space and try again.</source>
        <translation>Onvoldoende spasie op UOS. Vennig minstens %1G spasie en probeer weer.</translation>
    </message>
</context>
<context>
    <name>UserSelectFileSize</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/select/userselectfilesize.cpp" line="22"/>
        <source>Calculating</source>
        <translation>Berekening</translation>
    </message>
</context>
<context>
    <name>WaitTransferWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="32"/>
        <source>Waiting for transfer...</source>
        <translation>Wag vir oorgedra...</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="37"/>
        <source>Please select the data to transfer on Windows</source>
        <translation>Kies asseblief die data wat op Windows oorgedra moet word</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="47"/>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="98"/>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="99"/>
        <source>Close</source>
        <translation>Sluit</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="101"/>
        <source>This operation will clear the transmission progress, Do you want to continue.</source>
        <translation>Hierdie operasie sal die oorgedra-vooruitgang wyskryf, Wil jy voortgaan?</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/transfer/waittransferwidget.cpp" line="102"/>
        <source>This operation is not recoverable</source>
        <translation>Hierdie operasie kan nie herstel word nie</translation>
    </message>
</context>
<context>
    <name>ZipFileProcessResultWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="32"/>
        <source>Exit</source>
        <translation>Verlaat</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="49"/>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="84"/>
        <source>Back up succeed</source>
        <translation>Back-up suksesvol</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="90"/>
        <source>Congratulations, Your Information has been Successfully Backed Up.</source>
        <translation>Gefeliciteerd, jou inligting is suksesvol back-up gegee.</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="95"/>
        <source>Go to View</source>
        <translation>Gaan na sien</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocessresultwidget.cpp" line="120"/>
        <source>Back up failed</source>
        <translation>Back-up misluk</translation>
    </message>
</context>
<context>
    <name>ZipFileProcessWidget</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="44"/>
        <source>Packing  %1</source>
        <translation>Pak %1</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="53"/>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="101"/>
        <source>Transfer will be completed in %1 minutes</source>
        <translation>Die oorgedra sal voltooi word in %1 minute</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="56"/>
        <source>Transfer will be completed in %1 secondes</source>
        <translation>Die oorgedra sal voltooi word in %1 sekondes</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipfileprocesswidget.cpp" line="84"/>
        <source>Creating Backup File...</source>
        <translation>Aanmaak van back-up lêer...</translation>
    </message>
</context>
<context>
    <name>ZipWork</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipworker.cpp" line="283"/>
        <source>%1 File compression failed</source>
        <translation>&apos;%1 Lêer komprimering het misluk&apos;</translation>
    </message>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/getbackup/zipworker.cpp" line="213"/>
        <source>Back up file done</source>
        <translation>Back-up lêer voltooi</translation>
    </message>
</context>
<context>
    <name>data_transfer_core::MainWindowPrivate</name>
    <message>
        <location filename="../../src/plugins/data-transfer/core/gui/linux/mainwindow_p_linux.cpp" line="32"/>
        <source>UOS data transfer</source>
        <translation>UOS data oorgedra</translation>
    </message>
</context>
</TS>